==> versatile-kernel-2.6.18.1-compiled.tar.bz2: linux-2.6.18.1/drivers/block/aoe/aoe.mod.c <==
#include <linux/module.h>
#include <linux/vermagic.h>
#include <linux/compiler.h>

MODULE_INFO(vermagic, VERMAGIC_STRING);

struct module __this_module
__attribute__((section(".gnu.linkonce.this_module"))) = {
 .name = KBUILD_MODNAME,
 .init = init_module,
#ifdef CONFIG_MODULE_UNLOAD
 .exit = cleanup_module,
#endif
};

static const struct modversion_info ____versions[]
__attribute_used__
__attribute__((section("__versions"))) = {
	{ 0xe3e52f33, "struct_module" },
	{ 0xb9f66ce8, "kmem_cache_destroy" },
	{ 0x12da5bb2, "__kmalloc" },
	{ 0x9afe9c91, "__mod_timer" },
	{ 0xd0a46d42, "alloc_disk" },
	{ 0x17a142df, "__copy_from_user" },
	{ 0xfb5e401, "mem_map" },
	{ 0x98082893, "__copy_to_user" },
	{ 0x75b38522, "del_timer" },
	{ 0x97255bdf, "strlen" },
	{ 0xc7ec6c27, "strspn" },
	{ 0xdff32ed7, "class_device_destroy" },
	{ 0xb3bbf481, "class_device_create" },
	{ 0xb13d73c9, "malloc_sizes" },
	{ 0xc874588a, "blk_queue_bounce" },
	{ 0x77799132, "skb_clone" },
	{ 0x7ad5eec9, "schedule_work" },
	{ 0xac54fc9f, "mempool_destroy" },
	{ 0x323222ba, "mutex_unlock" },
	{ 0x6c1ce5ce, "strcspn" },
	{ 0x7d11c268, "jiffies" },
	{ 0x12f237eb, "__kzalloc" },
	{ 0xfc3164cf, "__pskb_pull_tail" },
	{ 0x183fa88b, "mempool_alloc_slab" },
	{ 0xfa2a45e, "__memzero" },
	{ 0x5f754e5a, "memset" },
	{ 0x829871bc, "__down_interruptible_failed" },
	{ 0xdd132261, "printk" },
	{ 0x859204af, "sscanf" },
	{ 0x4b7bba11, "del_gendisk" },
	{ 0xeb7174d3, "dev_base" },
	{ 0x84b183ae, "strncmp" },
	{ 0xb97d4c9c, "mutex_lock" },
	{ 0x2d3f1dd1, "class_create" },
	{ 0x71a50dbc, "register_blkdev" },
	{ 0xc1b5cb34, "dev_remove_pack" },
	{ 0xe60c1553, "sysfs_remove_link" },
	{ 0x8a99a016, "mempool_free_slab" },
	{ 0xe284e7a5, "bio_endio" },
	{ 0x8320bea8, "__umodsi3" },
	{ 0xeac1c4af, "unregister_blkdev" },
	{ 0x9dba41c4, "skb_over_panic" },
	{ 0xab53b0a8, "mempool_alloc" },
	{ 0xfc88a3f6, "__alloc_skb" },
	{ 0x2e1a872b, "blk_queue_make_request" },
	{ 0xa07b7cbe, "kfree_skb" },
	{ 0xed33cbfd, "put_disk" },
	{ 0x1f7cc628, "mempool_create" },
	{ 0x129bff55, "skb_under_panic" },
	{ 0x39a5ea2, "register_chrdev" },
	{ 0x8c21628f, "sysfs_create_file" },
	{ 0x683a3221, "param_set_copystring" },
	{ 0x62aba95, "mempool_free" },
	{ 0x86ea1981, "kmem_cache_create" },
	{ 0x6cb34e5, "init_waitqueue_head" },
	{ 0x35fe47a1, "init_timer" },
	{ 0xf6ebc03b, "net_ratelimit" },
	{ 0xc818ff24, "kmem_cache_zalloc" },
	{ 0xfb7d9c45, "__udivsi3" },
	{ 0x37a0cba, "kfree" },
	{ 0x9d669763, "memcpy" },
	{ 0x801678, "flush_scheduled_work" },
	{ 0x7d278870, "add_disk" },
	{ 0xc192d491, "unregister_chrdev" },
	{ 0x320b40d1, "class_destroy" },
	{ 0x1042cbb5, "__up_wakeup" },
	{ 0x25da070, "snprintf" },
	{ 0x147b3e42, "bdget" },
	{ 0xadd44d33, "dev_add_pack" },
	{ 0x93304684, "param_get_string" },
	{ 0x243cfc07, "dev_queue_xmit" },
	{ 0xda0efd46, "bdput" },
};

static const char __module_depends[]
__attribute_used__
__attribute__((section(".modinfo"))) =
"depends=";


MODULE_INFO(srcversion, "1154FEB66D6B77EDF4705D1");

==> versatile-kernel-2.6.19.1-compiled.tar.bz2: linux-2.6.19.1/drivers/block/aoe/aoe.mod.c <==
#include <linux/module.h>
#include <linux/vermagic.h>
#include <linux/compiler.h>

MODULE_INFO(vermagic, VERMAGIC_STRING);

struct module __this_module
__attribute__((section(".gnu.linkonce.this_module"))) = {
 .name = KBUILD_MODNAME,
 .init = init_module,
#ifdef CONFIG_MODULE_UNLOAD
 .exit = cleanup_module,
#endif
};

static const struct modversion_info ____versions[]
__attribute_used__
__attribute__((section("__versions"))) = {
	{ 0x528a560b, "struct_module" },
	{ 0xaadf600c, "kmem_cache_destroy" },
	{ 0x12da5bb2, "__kmalloc" },
	{ 0x9afe9c91, "__mod_timer" },
	{ 0xba36db29, "alloc_disk" },
	{ 0xfbc74f64, "__copy_from_user" },
	{ 0x2f9838ed, "mem_map" },
	{ 0x89b301d4, "param_get_int" },
	{ 0x67c2fa54, "__copy_to_user" },
	{ 0x75b38522, "del_timer" },
	{ 0x97255bdf, "strlen" },
	{ 0xc7ec6c27, "strspn" },
	{ 0xc2bf2eb7, "class_device_destroy" },
	{ 0xaafc1419, "class_device_create" },
	{ 0xb13d73c9, "malloc_sizes" },
	{ 0x4b0fa5ee, "blk_queue_bounce" },
	{ 0xcbb94c95, "skb_clone" },
	{ 0x7ad5eec9, "schedule_work" },
	{ 0xac54fc9f, "mempool_destroy" },
	{ 0x323222ba, "mutex_unlock" },
	{ 0x98bd6f46, "param_set_int" },
	{ 0x6c1ce5ce, "strcspn" },
	{ 0x358c1151, "sysfs_remove_group" },
	{ 0x7d11c268, "jiffies" },
	{ 0x12f237eb, "__kzalloc" },
	{ 0x5915105c, "__pskb_pull_tail" },
	{ 0x183fa88b, "mempool_alloc_slab" },
	{ 0xfa2a45e, "__memzero" },
	{ 0x5f754e5a, "memset" },
	{ 0x829871bc, "__down_interruptible_failed" },
	{ 0xdd132261, "printk" },
	{ 0x859204af, "sscanf" },
	{ 0x8028db6b, "sysfs_create_group" },
	{ 0x2035e134, "del_gendisk" },
	{ 0x498cd8f5, "dev_base" },
	{ 0x84b183ae, "strncmp" },
	{ 0xb97d4c9c, "mutex_lock" },
	{ 0xa956b923, "class_create" },
	{ 0x71a50dbc, "register_blkdev" },
	{ 0x84ab54b3, "dev_remove_pack" },
	{ 0x8a99a016, "mempool_free_slab" },
	{ 0x37fa3b81, "bio_endio" },
	{ 0x8320bea8, "__umodsi3" },
	{ 0xeac1c4af, "unregister_blkdev" },
	{ 0xe4e7f697, "skb_over_panic" },
	{ 0xab53b0a8, "mempool_alloc" },
	{ 0xa0480cc0, "__alloc_skb" },
	{ 0x7b7d0a79, "blk_queue_make_request" },
	{ 0x4c6ea477, "kfree_skb" },
	{ 0x5a44612c, "put_disk" },
	{ 0x1f7cc628, "mempool_create" },
	{ 0x6b2dc060, "dump_stack" },
	{ 0x6fda369f, "skb_under_panic" },
	{ 0xf8af26, "register_chrdev" },
	{ 0x683a3221, "param_set_copystring" },
	{ 0x62aba95, "mempool_free" },
	{ 0x86ea1981, "kmem_cache_create" },
	{ 0x6cb34e5, "init_waitqueue_head" },
	{ 0x35fe47a1, "init_timer" },
	{ 0xf6ebc03b, "net_ratelimit" },
	{ 0xc818ff24, "kmem_cache_zalloc" },
	{ 0xfb7d9c45, "__udivsi3" },
	{ 0x37a0cba, "kfree" },
	{ 0x9d669763, "memcpy" },
	{ 0x801678, "flush_scheduled_work" },
	{ 0xc455ed01, "add_disk" },
	{ 0xc192d491, "unregister_chrdev" },
	{ 0xb43dd575, "class_destroy" },
	{ 0x1042cbb5, "__up_wakeup" },
	{ 0x25da070, "snprintf" },
	{ 0xbfb395f9, "bdget" },
	{ 0x44c7bd51, "dev_add_pack" },
	{ 0x93304684, "param_get_string" },
	{ 0x348b9afe, "dev_queue_xmit" },
	{ 0x8287f6f1, "bdput" },
};

static const char __module_depends[]
__attribute_used__
__attribute__((section(".modinfo"))) =
"depends=";


MODULE_INFO(srcversion, "2BAC7D446BE06211561F2CE");
